package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.LcdReceiveUser;
import com.ruoyi.system.service.ILcdReceiveUserService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 接收消息用户Controller
 *
 * @author ruoyi
 * @date 2023-01-14
 */
@Api(tags = "LcdReceiveUserController",description = "用户信息-接收消息")
@RestController
@RequestMapping("/system/user")
public class LcdReceiveUserController extends BaseController
{
    @Autowired
    private ILcdReceiveUserService lcdReceiveUserService;

    /**
     * 查询用户列表
     */
    @ApiOperation("查询接收消息用户列表")
    @PreAuthorize("@ss.hasPermi('system:user:list')")
    @GetMapping("/list")
    public TableDataInfo list(LcdReceiveUser lcdReceiveUser)
    {
        startPage();
        List<LcdReceiveUser> list = lcdReceiveUserService.selectLcdReceiveUserList(lcdReceiveUser);
        return getDataTable(list);
    }

    /**
     * 导出接收消息用户列表
     */
    @ApiOperation("导出接收消息用户列表")
    @PreAuthorize("@ss.hasPermi('system:user:export')")
    @Log(title = "接收消息用户", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, LcdReceiveUser lcdReceiveUser)
    {
        List<LcdReceiveUser> list = lcdReceiveUserService.selectLcdReceiveUserList(lcdReceiveUser);
        ExcelUtil<LcdReceiveUser> util = new ExcelUtil<LcdReceiveUser>(LcdReceiveUser.class);
        util.exportExcel(response, list, "接收消息用户数据");
    }

    /**
     * 获取接收消息用户详细信息
     */
    @ApiOperation("获取接收消息用户详细信息")
    @PreAuthorize("@ss.hasPermi('system:user:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(lcdReceiveUserService.selectLcdReceiveUserById(id));
    }

    /**
     * 新增接收消息用户
     */
    @ApiOperation("新增接收消息用户")
    @PreAuthorize("@ss.hasPermi('system:user:add')")
    @Log(title = "接收消息用户", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody LcdReceiveUser lcdReceiveUser)
    {
        return toAjax(lcdReceiveUserService.insertLcdReceiveUser(lcdReceiveUser));
    }

    /**
     * 修改接收消息用户
     */
    @ApiOperation("修改接收消息用户")
    @PreAuthorize("@ss.hasPermi('system:user:edit')")
    @Log(title = "接收消息用户", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody LcdReceiveUser lcdReceiveUser)
    {
        return toAjax(lcdReceiveUserService.updateLcdReceiveUser(lcdReceiveUser));
    }

    /**
     * 删除接收消息用户
     */
    @ApiOperation("删除接收消息用户")
    @PreAuthorize("@ss.hasPermi('system:user:remove')")
    @Log(title = "接收消息用户", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(lcdReceiveUserService.deleteLcdReceiveUserByIds(ids));
    }
}
