package com.ruoyi.system.service.impl;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.LcdInfoMapper;
import com.ruoyi.system.domain.LcdInfo;
import com.ruoyi.system.service.ILcdInfoService;

/**
 * 消息Service业务层处理
 *
 * @author ruoyi
 * @date 2023-01-14
 */
@Service
public class LcdInfoServiceImpl implements ILcdInfoService {
    @Autowired
    private LcdInfoMapper lcdInfoMapper;

    /**
     * 查询消息
     *
     * @param id 消息主键
     * @return 消息
     */
    @Override
    public LcdInfo selectLcdInfoById(Long id) {
        return lcdInfoMapper.selectLcdInfoById(id);
    }

    /**
     * 查询消息列表
     *
     * @param lcdInfo 消息
     * @return 消息
     */
    @Override
    public List<LcdInfo> selectLcdInfoList(LcdInfo lcdInfo) {
        return lcdInfoMapper.selectLcdInfoList(lcdInfo);
    }

    /**
     * 新增消息
     *
     * @param lcdInfo 消息
     * @return 结果
     */
    @Override
    public int insertLcdInfo(LcdInfo lcdInfo) {
        lcdInfo.setCreateTime(DateUtils.getNowDate());
        return lcdInfoMapper.insertLcdInfo(lcdInfo);
    }

    /**
     * 修改消息
     *
     * @param lcdInfo 消息
     * @return 结果
     */
    @Override
    public int updateLcdInfo(LcdInfo lcdInfo) {
        lcdInfo.setUpdateTime(DateUtils.getNowDate());
        return lcdInfoMapper.updateLcdInfo(lcdInfo);
    }

    /**
     * 批量删除消息
     *
     * @param ids 需要删除的消息主键
     * @return 结果
     */
    @Override
    public int deleteLcdInfoByIds(Long[] ids) {
        return lcdInfoMapper.deleteLcdInfoByIds(ids);
    }

    /**
     * 删除消息信息
     *
     * @param id 消息主键
     * @return 结果
     */
    @Override
    public int deleteLcdInfoById(Long id) {
        return lcdInfoMapper.deleteLcdInfoById(id);
    }

    /**
     * 搜索消息列表.
     *
     * @param title
     * @param lcdTimeLeft
     * @param lcdTimeRight
     * @return 结果
     */
    @Override
    public List<LcdInfo> selectList(String title, Date lcdTimeLeft, Date lcdTimeRight) {
        if (title != null) {
            //标题不为空则判断时间
            if (lcdTimeLeft != null && lcdTimeRight != null) {
                //时间不为空 ，且左时间在右时间之前
                if (lcdTimeLeft.before(lcdTimeRight)) {
                    return lcdInfoMapper.selectLcdListByTitleOrlcdTime(title, lcdTimeLeft, lcdTimeRight);
                } else {
                    List list = new ArrayList<>();
                    list.add("时间顺序错误");
                    return list;
                }
            } else {
                //时间为空
                return lcdInfoMapper.selectLcdListByTitleOrlcdTime(title, null, null);
            }
        } else {
            //标题为空
            if (lcdTimeLeft != null && lcdTimeRight != null && lcdTimeLeft.before(lcdTimeRight)) {
                //时间不为空
                return lcdInfoMapper.selectLcdListByTitleOrlcdTime(null, lcdTimeLeft, lcdTimeRight);
            }
        }
        LcdInfo lcdInfo = new LcdInfo();
        return lcdInfoMapper.selectLcdInfoList(lcdInfo);
    }
}
